@@ -266,6 +266,9 @@ class CommandLineOptionsTest(TestCase):
     def test_zzz_logtostdout(self):
         """Testing redirecting log to stdout."""
 
+        fd, dummylogfn = tempfile.mkstemp(prefix='easybuild-dummy', suffix='.log')
+        os.close(fd)
+
         for stdout_arg in ['--logtostdout', '-l']:
 
             _stdout = sys.stdout
@@ -282,7 +285,7 @@ class CommandLineOptionsTest(TestCase):
                     stdout_arg,
                    ]
             try:
-                main((args, None))
+                main((args, dummylogfn))
             except (SystemExit, Exception), err:
                 myerr = err
 
@@ -298,6 +301,8 @@ class CommandLineOptionsTest(TestCase):
             # cleanup
             os.remove(fn)
 
+        if os.path.exists(dummylogfn):
+            os.remove(dummylogfn)
         fancylogger.logToFile(self.logfile)
 
     def test_avail_easyconfig_params(self):
@@ -305,6 +310,10 @@ class CommandLineOptionsTest(TestCase):
 
         def run_test(custom=None, extra_params=[]):
             """Inner function to run actual test in current setting."""
+
+            fd, dummylogfn = tempfile.mkstemp(prefix='easybuild-dummy', suffix='.log')
+            os.close(fd)
+
             for avail_arg in [
                               '-a',
                               '--avail-easyconfig-params',
@@ -321,7 +330,7 @@ class CommandLineOptionsTest(TestCase):
                     args.extend(['-e', custom])
 
                 try:
-                    main((args, None))
+                    main((args, dummylogfn))
                 except (SystemExit, Exception), err:
                     pass
                 outtxt = read_file(self.logfile)
@@ -345,6 +354,9 @@ class CommandLineOptionsTest(TestCase):
                                     (param, avail_arg, args, outtxt)
                                     )
 
+            if os.path.exists(dummylogfn):
+                os.remove(dummylogfn)
+
         # also check whether available custom easyconfig parameters are listed
         orig_sys_path = sys.path
 
@@ -366,12 +378,15 @@ class CommandLineOptionsTest(TestCase):
     def test_list_toolchains(self):
         """Test listing known compiler toolchains."""
 
+        fd, dummylogfn = tempfile.mkstemp(prefix='easybuild-dummy', suffix='.log')
+        os.close(fd)
+
         args = [
                 '--list-toolchains',
                 '--unittest-file=%s' % self.logfile,
                ]
         try:
-            main((args, None))
+            main((args, dummylogfn))
         except (SystemExit, Exception), err:
             pass
         outtxt = read_file(self.logfile)
@@ -379,11 +394,21 @@ class CommandLineOptionsTest(TestCase):
         info_msg = r"INFO List of known toolchains \(toolchainname: module\[,module\.\.\.\]\):"
         self.assertTrue(re.search(info_msg, outtxt), "Info message with list of known compiler toolchains")
         for tc in ["dummy", "goalf", "ictce"]:
-            self.assertTrue(re.search("%s: " % tc, outtxt), "Toolchain %s is included in list of known compiler toolchains")
+            res = re.findall("^\s*%s: " % tc, outtxt, re.M)
+            self.assertTrue(res, "Toolchain %s is included in list of known compiler toolchains" % tc)
+            # every toolchain should only be mentioned once
+            n = len(res)
+            self.assertEqual(n, 1, "Toolchain %s is only mentioned once (count: %d)" % (tc, n))
+
+        if os.path.exists(dummylogfn):
+            os.remove(dummylogfn)
 
     def test_list_easyblocks(self):
         """Test listing easyblock hierarchy."""
 
+        fd, dummylogfn = tempfile.mkstemp(prefix='easybuild-dummy', suffix='.log')
+        os.close(fd)
+
         # adjust PYTHONPATH such that test easyblocks are found
         orig_sys_path = sys.path
 
@@ -404,7 +429,7 @@ class CommandLineOptionsTest(TestCase):
                     '--unittest-file=%s' % self.logfile,
                    ]
             try:
-                main((args, None))
+                main((args, dummylogfn))
             except (SystemExit, Exception), err:
                 pass
             outtxt = read_file(self.logfile)
@@ -426,7 +451,7 @@ class CommandLineOptionsTest(TestCase):
                 '--unittest-file=%s' % self.logfile,
                ]
         try:
-            main((args, None))
+            main((args, dummylogfn))
         except (SystemExit, Exception), err:
             pass
         outtxt = read_file(self.logfile)
@@ -439,19 +464,25 @@ class CommandLineOptionsTest(TestCase):
 
             self.assertTrue(re.search(pat, outtxt), "Pattern '%s' is found in output of --list-easyblocks: %s" % (pat, outtxt))
 
+        if os.path.exists(dummylogfn):
+            os.remove(dummylogfn)
 
         # restore original Python search path
         sys.path = orig_sys_path
 
     def test_search(self):
         """Test searching for easyconfigs."""
+
+        fd, dummylogfn = tempfile.mkstemp(prefix='easybuild-dummy', suffix='.log')
+        os.close(fd)
+
         args = [
                 '--search=gzip',
                 '--robot=%s' % os.path.join(os.path.dirname(__file__), 'easyconfigs'),
                 '--unittest-file=%s' % self.logfile,
                ]
         try:
-            main((args, None))
+            main((args, dummylogfn))
         except (SystemExit, Exception), err:
             pass
         outtxt = open(self.logfile, 'r').read()
@@ -461,6 +492,9 @@ class CommandLineOptionsTest(TestCase):
         for ec in ["gzip-1.4.eb", "gzip-1.4-GCC-4.6.3.eb"]:
             self.assertTrue(re.search("%s$" % ec, outtxt, re.M), "Found easyconfig %s in '%s'" % (ec, outtxt))
 
+        if os.path.exists(dummylogfn):
+            os.remove(dummylogfn)
+
     def test_no_such_software(self):
         """Test using no arguments."""
 
